@@ -93,16 +93,9 @@ def setup():
   if os.path.isdir(app_root) or os.path.exists(app_root):
     raise OSError('{} already exists!'.format(app_root))
   
-  app_mode = ''
-  while app_mode not in [ 'SHELL', 'PYTHON' ]:
-    app_mode = input('Setup Project for Which Execution Mode?\nPlease Enter SHELL or PYTHON: ').upper().strip()
-    if app_mode not in [ 'SHELL', 'PYTHON' ]:
-      print('Invalid Input')
-  
   print('\nSUMMARY:\n')
   print('Project Name: {}'.format(app_name))
   print('Project Path: {}/{}'.format(app_path, app_name))
-  print('Execution Mode: {}'.format(app_mode))
   
   input('\nPress ENTER if this is correct or Ctrl + C to Abort...\n')
   
@@ -110,16 +103,11 @@ def setup():
   
   print('Creating Directory: {}'.format(app_root))
   print('Creating Directory: {}/config'.format(app_root))
-  print('Creating Directory: {}/logs'.format(app_root))
-  print('Creating Directory: {}/data'.format(app_root))
-  print('Creating Directory: {}/temp'.format(app_root))
-  if app_mode == 'SHELL': print('Creating Directory: {}/scripts'.format(app_root))
-  if app_mode == 'PYTHON': print('Creating Directory: {}/python'.format(app_root))
+  print('Creating Directory: {}/workers'.format(app_root))
   
   os.makedirs(app_root)
   os.makedirs('{}/config'.format(app_root))
-  if app_mode == 'SHELL': os.makedirs('{}/scripts'.format(app_root))
-  if app_mode == 'PYTHON': os.makedirs('{}/python'.format(app_root))
+  os.makedirs('{}/workers'.format(app_root))
   
   print('Creating Application Profile: {}/config/app_profile'.format(app_root))
   with open('{}/config/app_profile'.format(app_root), 'w') as app_profile:
@@ -127,26 +115,23 @@ def setup():
     app_profile.write('# This app_profile will be sourced prior to execution of PyRunner job.\n')
     app_profile.write('# NOTE: Only variables with "APP_" prefix will be available during job.\n')
     app_profile.write('#       All other variables will be discarded.\n\n')
+    app_profile.write('export APP_VERSION=0.0.1\n\n')
     app_profile.write('export APP_NAME="{}"\n'.format(app_name))
     app_profile.write('export APP_ROOT_DIR="$(cd $(dirname ${BASH_SOURCE})/..; pwd)"\n')
     app_profile.write('export APP_CONFIG_DIR="${APP_ROOT_DIR}/config"\n')
-    app_profile.write('export APP_TEMP_DIR="${APP_ROOT_DIR}/.temp"\n')
-    app_profile.write('export APP_DATA_DIR="${APP_ROOT_DIR}/data"\n')
+    app_profile.write('export APP_TEMP_DIR="${APP_ROOT_DIR}/temp"\n')
     app_profile.write('export APP_ROOT_LOG_DIR="${APP_ROOT_DIR}/logs"\n')
     app_profile.write('export APP_LOG_RETENTION="30"\n')
-    if app_mode == 'SHELL': app_profile.write('export APP_SCRIPTS_DIR="${APP_ROOT_DIR}/scripts"\n')
-    if app_mode == 'PYTHON': app_profile.write('export APP_WORKER_DIR="${APP_ROOT_DIR}/python"\n\n')
+    app_profile.write('export APP_WORKER_DIR="${APP_ROOT_DIR}/workers"\n\n')
     app_profile.write('DATE=$(date +"%Y-%m-%d")\n')
     app_profile.write('export APP_EXEC_TIMESTAMP=$(date +"%Y%m%d_%H%M%S")\n\n')
     app_profile.write('export APP_LOG_DIR="${APP_ROOT_LOG_DIR}/${DATE}"\n\n')
     app_profile.write('if [ ! -e ${APP_LOG_DIR}  ]; then mkdir -p ${APP_LOG_DIR}; fi\n')
-    app_profile.write('if [ ! -e ${APP_TEMP_DIR} ]; then mkdir ${APP_TEMP_DIR}; fi\n')
-    app_profile.write('if [ ! -e ${APP_DATA_DIR} ]; then mkdir ${APP_DATA_DIR}; fi\n')
+    app_profile.write('if [ ! -e ${APP_TEMP_DIR} ]; then mkdir -p ${APP_TEMP_DIR}; fi\n')
   
   print('Creating Blank Process List File: {}/config/{}.lst'.format(app_root, app_name))
   with open('{}/config/{}.lst'.format(app_root, app_name), 'w') as lst_file:
-    if app_mode == 'SHELL': lst_file.write('{}\n\n'.format(constants.HEADER_SHELL))
-    if app_mode == 'PYTHON': lst_file.write('{}\n\n'.format(constants.HEADER_PYTHON))
+    lst_file.write('{}\n\n'.format(constants.HEADER_PYTHON))
   
   print('Creating Driver Program: {}/{}.py'.format(app_root, app_name))
   with open('{}/{}.py'.format(app_root, app_name), 'w') as main_file:
